#!/usr/bin/perl -w

# Load testing for Template::Parser::LocalizeNewlines

use strict;
use lib ();
use UNIVERSAL 'isa';
use File::Spec::Functions ':ALL';
BEGIN {
	$| = 1;
	unless ( $ENV{HARNESS_ACTIVE} ) {
		require FindBin;
		chdir ($FindBin::Bin = $FindBin::Bin); # Avoid a warning
		lib->import( catdir( updir(), updir(), 'modules') );
	}
}

use Test::More tests => 1;

# Does the module load
use_ok('Template::Parser::LocalizeNewlines');

exit(0);
